@@ -335,6 +335,8 @@ case "notte":  					$messaggio = "night"; break;
 case "notti":  					$messaggio = "nights"; break;
 case "cambia date":  				$messaggio = "change dates"; break;
 case "Per questa tariffa si deve inserire un minimo di":	$messaggio = "For this rate you have to insert at least"; break;
+case "Secondo cognome":  			$messaggio = "Second surname"; break;
+case "2° cognome":  				$messaggio = "2nd surname"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
@@ -624,9 +626,11 @@ case "var_fr_cambia_date":  			$messaggio = "var_phr_change_dates"; break;
 case "var_fr_Per_questa_tariffa_si_deve_inserire_un_minimo_di":	$messaggio = "var_phr_For_this_rate_you_have_to_insert_at_least"; break;
 case "var_":  		$messaggio = "var_"; break;
 case "var_":  		$messaggio = "var_"; break;
+case "var_chiedi_cognome2":  			$messaggio = "var_ask_surname2"; break;
+case "var_fr_Secondo_cognome":  		$messaggio = "var_phr_Second_surname"; break;
 } # fine switch ($messaggio)
 } # fine else if (substr((string) $messaggio,0,4) != "var_")
 
 
 
-?>
\ No newline at end of file
+?>
